@@ -2,15 +2,7 @@
 ### Encoding: ISO8859-1
 
 ###################################################
-### code chunk number 1: setup
-###################################################
-options(prompt = "R> ")
-options(SweaveHooks = list(
-  cex = function() par(cex.lab = 1.3, cex.axis = 1.3)))
-
-
-###################################################
-### code chunk number 2: apt.Rnw:155-160
+### code chunk number 1: apt.Rnw:85-90
 ###################################################
 library(apt)
 data(daVich)
@@ -20,7 +12,7 @@ bsStat(daVich)
 
 
 ###################################################
-### code chunk number 3: apt.Rnw:165-168
+### code chunk number 2: apt.Rnw:95-98
 ###################################################
 library(urca)
 adf.xa <- ur.df(daCh,  type=c("trend"), lags=3)
@@ -28,7 +20,7 @@ adf.xa
 
 
 ###################################################
-### code chunk number 4: apt.Rnw:172-173
+### code chunk number 3: apt.Rnw:102-103
 ###################################################
 plot(adf.xa)
 
